==> zio-aws-elasticache_3-5.17.147.1-sources.jar: zio/aws/elasticache/model/CacheParameterGroup.scala <==
package zio.aws.elasticache.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CacheParameterGroup(
    cacheParameterGroupName: Option[String] = None,
    cacheParameterGroupFamily: Option[String] = None,
    description: Option[String] = None,
    isGlobal: Option[Boolean] = None,
    arn: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticache.model.CacheParameterGroup = {
    import CacheParameterGroup.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticache.model.CacheParameterGroup
      .builder()
      .optionallyWith(
        cacheParameterGroupName.map(value => value: java.lang.String)
      )(_.cacheParameterGroupName)
      .optionallyWith(
        cacheParameterGroupFamily.map(value => value: java.lang.String)
      )(_.cacheParameterGroupFamily)
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(isGlobal.map(value => value: java.lang.Boolean))(
        _.isGlobal
      )
      .optionallyWith(arn.map(value => value: java.lang.String))(_.arn)
      .build()
  }
  def asReadOnly: zio.aws.elasticache.model.CacheParameterGroup.ReadOnly =
    zio.aws.elasticache.model.CacheParameterGroup.wrap(buildAwsValue())
}
object CacheParameterGroup {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticache.model.CacheParameterGroup
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticache.model.CacheParameterGroup =
      zio.aws.elasticache.model.CacheParameterGroup(
        cacheParameterGroupName.map(value => value),
        cacheParameterGroupFamily.map(value => value),
        description.map(value => value),
        isGlobal.map(value => value),
        arn.map(value => value)
      )
    def cacheParameterGroupName: Option[String]
    def cacheParameterGroupFamily: Option[String]
    def description: Option[String]
    def isGlobal: Option[Boolean]
    def arn: Option[String]
    def getCacheParameterGroupName: ZIO[Any, AwsError, String] = AwsError
      .unwrapOptionField("cacheParameterGroupName", cacheParameterGroupName)
    def getCacheParameterGroupFamily: ZIO[Any, AwsError, String] = AwsError
      .unwrapOptionField("cacheParameterGroupFamily", cacheParameterGroupFamily)
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getIsGlobal: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("isGlobal", isGlobal)
    def getArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("arn", arn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticache.model.CacheParameterGroup
  ) extends zio.aws.elasticache.model.CacheParameterGroup.ReadOnly {
    override val cacheParameterGroupName: Option[String] =
      scala.Option(impl.cacheParameterGroupName()).map(value => value: String)
    override val cacheParameterGroupFamily: Option[String] =
      scala.Option(impl.cacheParameterGroupFamily()).map(value => value: String)
    override val description: Option[String] =
      scala.Option(impl.description()).map(value => value: String)
    override val isGlobal: Option[Boolean] =
      scala.Option(impl.isGlobal()).map(value => value: Boolean)
    override val arn: Option[String] =
      scala.Option(impl.arn()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticache.model.CacheParameterGroup
  ): zio.aws.elasticache.model.CacheParameterGroup.ReadOnly = new Wrapper(impl)
}

==> zio-aws-elasticache_3-5.17.206.1-sources.jar: zio/aws/elasticache/model/CacheParameterGroup.scala <==
package zio.aws.elasticache.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CacheParameterGroup(
    cacheParameterGroupName: Optional[String] = Optional.Absent,
    cacheParameterGroupFamily: Optional[String] = Optional.Absent,
    description: Optional[String] = Optional.Absent,
    isGlobal: Optional[Boolean] = Optional.Absent,
    arn: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticache.model.CacheParameterGroup = {
    import CacheParameterGroup.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticache.model.CacheParameterGroup
      .builder()
      .optionallyWith(
        cacheParameterGroupName.map(value => value: java.lang.String)
      )(_.cacheParameterGroupName)
      .optionallyWith(
        cacheParameterGroupFamily.map(value => value: java.lang.String)
      )(_.cacheParameterGroupFamily)
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(isGlobal.map(value => value: java.lang.Boolean))(
        _.isGlobal
      )
      .optionallyWith(arn.map(value => value: java.lang.String))(_.arn)
      .build()
  }
  def asReadOnly: zio.aws.elasticache.model.CacheParameterGroup.ReadOnly =
    zio.aws.elasticache.model.CacheParameterGroup.wrap(buildAwsValue())
}
object CacheParameterGroup {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticache.model.CacheParameterGroup
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticache.model.CacheParameterGroup =
      zio.aws.elasticache.model.CacheParameterGroup(
        cacheParameterGroupName.map(value => value),
        cacheParameterGroupFamily.map(value => value),
        description.map(value => value),
        isGlobal.map(value => value),
        arn.map(value => value)
      )
    def cacheParameterGroupName: Optional[String]
    def cacheParameterGroupFamily: Optional[String]
    def description: Optional[String]
    def isGlobal: Optional[Boolean]
    def arn: Optional[String]
    def getCacheParameterGroupName: ZIO[Any, AwsError, String] = AwsError
      .unwrapOptionField("cacheParameterGroupName", cacheParameterGroupName)
    def getCacheParameterGroupFamily: ZIO[Any, AwsError, String] = AwsError
      .unwrapOptionField("cacheParameterGroupFamily", cacheParameterGroupFamily)
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getIsGlobal: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("isGlobal", isGlobal)
    def getArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("arn", arn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticache.model.CacheParameterGroup
  ) extends zio.aws.elasticache.model.CacheParameterGroup.ReadOnly {
    override val cacheParameterGroupName: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.cacheParameterGroupName())
        .map(value => value: String)
    override val cacheParameterGroupFamily: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.cacheParameterGroupFamily())
        .map(value => value: String)
    override val description: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => value: String)
    override val isGlobal: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.isGlobal())
      .map(value => value: Boolean)
    override val arn: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticache.model.CacheParameterGroup
  ): zio.aws.elasticache.model.CacheParameterGroup.ReadOnly = new Wrapper(impl)
}
